@@ -3,6 +3,7 @@ import logging
 import os
 import pytz
 import requests
+from time import sleep
 from datetime import datetime, timedelta
 from yaasr import STREAMS_FOLDER
 from yaasr.exceptions import StreamFolderNotFoud, StreamDataFileNotFoud
@@ -24,6 +25,25 @@ class YStream:
         self.destination_folder = destination_folder
         self.timezone = pytz.timezone('UTC')
 
+        # ranges to record (to avoid record 24h)
+        self.record_from_time = None
+        self.record_to_time = None
+
+        # chunks saved
+        self.saved_chunks = []
+
+        # Notify events to an external URL
+        self.notify_url = None
+
+    def set_notifications(self, url, headers={}, params={}):
+        self.notify_url = url
+        self.notify_extra_params = params
+        self.notify_headers = headers
+
+    def set_record_times(self, from_time=None, to_time=None):
+        self.record_from_time = from_time
+        self.record_to_time = to_time
+
     def get_stream_folder(self):
         """ Get the stream folder """
         stream_folder = os.path.join(self.streams_folder, self.name)
@@ -61,6 +81,22 @@ class YStream:
             chunk_bytes_size: chunk size to iterate over stream downloaded data
             chunk_time_size: split the audio files is chunk with this time
         """
+        if self.record_to_time is not None:
+            time_now = datetime.now(self.timezone).time()
+            while time_now >= self.record_to_time:
+                logger.info(f'Now {time_now} is late to save')
+                sleep(90)
+                time_now = datetime.now(self.timezone).time()
+                self.notify('LATE_TO_SAVE')
+
+        if self.record_from_time is not None:
+            time_now = datetime.now(self.timezone).time()
+            while time_now < self.record_from_time:
+                logger.info(f'Now {time_now} is early to save')
+                sleep(90)
+                time_now = datetime.now(self.timezone).time()
+                self.notify('EARLY_TO_SAVE')
+
         c = 0
         for stream in self.streams:
 
@@ -73,6 +109,7 @@ class YStream:
                 logger.error(f'Error connecting to stream {c} {url}: {e}')
                 continue
 
+            self.notify('START_RECORDING', {'url': url})
             extension = stream.get('extension', 'mp3')
             start, stream_path = self.generate_stream_path(extension=extension)
             self.last_start = start
@@ -88,7 +125,7 @@ class YStream:
                 now = datetime.now(self.timezone)
                 elapsed = now - start
                 if total_seconds > 0 and elapsed >= timedelta(seconds=total_seconds):
-                    logger.info(f'Finish recording {now}')
+                    logger.info(f'Finish total_seconds recording {now}')
                     break
                 elif now - last_start >= timedelta(seconds=chunk_time_size):
                     logger.info(f'{now} Elapsed {elapsed} Finish chunk {c}')
@@ -97,10 +134,16 @@ class YStream:
                     self.last_start = last_start
                     f.close()
                     f = open(stream_path, 'wb')
+                elif self.record_to_time is not None:
+                    time_now = datetime.now(self.timezone).time()
+                    if time_now >= self.record_to_time:
+                        logger.info(f'Finished day time {self.record_to_time} at {time_now}')
+                        break
 
             f.close()
             # last chunk
             self.chunk_finished(stream_path)
+            self.notify('FINISH_RECORDING', {'url': url})
             return stream_path
 
     def chunk_finished(self, stream_path):
@@ -112,9 +155,44 @@ class YStream:
             'started': self.last_start,
             'finished': datetime.now(self.timezone)
         }
+        self.saved_chunks.append(metadata)
+
+        ppfs = []
+        order = 0
         for ppf in self.post_process_functions:
+            order += 1
+            start_time = datetime.now(self.timezone)
             fn = ppf['fn']
             logger.info(f'Running {fn}')
             params = ppf.get('params', {})
             stream_path, metadata = fn(stream_path, metadata=metadata, **params)
             logger.info(f'{fn} finished')
+            elapsed = datetime.now(self.timezone) - start_time
+            ppfs.append({
+                'order': order,
+                'function': fn.__name__,
+                'elapsed': str(elapsed),
+                # TODO ensure pickle this 'params': params,
+                # TODO ensure pickle this  'metadata': metadata
+            })
+        data = {
+            'chunk_started': self.last_start.strftime(self.str_chunk_time_format)
+        }
+        data.update({'post_process_functions': ppfs})
+        self.notify('CHUNK_FINISHED', data)
+
+    def notify(self, event_name, data):
+        """ notify status to an external URL """
+        if self.notify_url is None:
+            return
+        url = self.notify_url
+        data.update(self.notify_extra_params)
+
+        # default params
+        data['event'] = event_name
+        data['stream_name'] = self.name
+
+        try:
+            requests.post(url=url, headers=self.notify_headers, params=data)
+        except Exception as e:
+            logger.error(f'Error notifying: {e}')
