@@ -2,6 +2,7 @@
 Iterate over priority domains and send data to server
 """
 import argparse
+from datetime import time
 import json
 import logging.config
 import os
@@ -46,7 +47,9 @@ def compress_and_google_store(stream,
                               total_seconds=300,
                               chunk_bytes_size=256,
                               chunk_time_size=60,
-                              audio_format='ogg'):
+                              audio_format='ogg',
+                              from_time=None,
+                              to_time=None):
     """ Shows stream info """
 
     ys = YStream(stream)
@@ -68,6 +71,14 @@ def compress_and_google_store(stream,
             }
         }
     ]
+
+    if from_time is not None:
+        parts = from_time.split(':')
+        ys.record_from_time = time(int(parts[0]), int(parts[1]))
+    if to_time is not None:
+        parts = to_time.split(':')
+        ys.record_to_time = time(int(parts[0]), int(parts[1]))
+
     ys.record(total_seconds=total_seconds, chunk_bytes_size=chunk_bytes_size, chunk_time_size=chunk_time_size)
 
 
@@ -82,6 +93,8 @@ def main():
     parser.add_argument('--total_seconds', nargs='?', default=0, type=int)
     parser.add_argument('--chunk_bytes_size', nargs='?', default=256, type=int)
     parser.add_argument('--chunk_time_size', nargs='?', default=1200, type=int)
+    parser.add_argument('--from_time', nargs='?', default=None, type=str, help="like 14:32")
+    parser.add_argument('--to_time', nargs='?', default=None, type=str, help="like 14:32")
     # compress parameters
     parser.add_argument('--audio_format', nargs='?', default='mp3', choices=['mp3', 'ogg'], type=str)
     parser.add_argument('--bucket_name', nargs='?', default=None, type=str)
@@ -109,13 +122,18 @@ def main():
             chunk_time_size=args.chunk_time_size
         )
     elif args.command == 'compress-and-google-store':
+        if args.bucket_name is None:
+            raise Exception('bucket name is required')
+
         return compress_and_google_store(
             stream=args.stream,
             bucket_name=args.bucket_name,
             total_seconds=args.total_seconds,
             chunk_bytes_size=args.chunk_bytes_size,
             chunk_time_size=args.chunk_time_size,
-            audio_format=args.audio_format
+            audio_format=args.audio_format,
+            from_time=args.from_time,
+            to_time=args.to_time
         )
     elif args.command == 'supervisor':
         return setup_supervisor(
